==> seplib-6.3.9.tar.gz: seplib-6.3.9/vplot/libvplot/fortstubs90.c <==
#include <sitedef.h>
#include "cfortran.h"
#include <unistd.h>
#include <vplot.h>
#include <cfortran.h>


int svpfilep (int filepntr)
{
extern FILE    *fdopen ();
    vp_filep (fdopen (filepntr, "w"));
}


FCALLSCFUN1(INT,svpfilep,VPFILEP,vpfilep,INT)
FCALLSCFUN5(INT,name_to_coltab,NAMETOCOLTAB,nametocoltab,PSTRING,INT,PFLOAT,PFLOAT,PFLOAT)
FCALLSCFUN6(INT,vp_area,VPAREA,vparea,PFLOAT,PFLOAT,INT,INT,INT,INT)
FCALLSCFUN6(INT,vp_uarea,VPUAREA,vpuarea,PFLOAT,PFLOAT,INT,INT,INT,INT)
FCALLSCFUN5(INT,vp_arrow,VPARROW,vparrow,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN5(INT,vp_uarrow,VPUARROW,vpuarrow,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_bgroup,VPBGROUP,vpbgroup,PSTRING)
FCALLSCFUN0(INT,vp_break,VPBREAK,vpbreak)
FCALLSCFUN4(INT,vp_clip,VPCLIP,vpclip,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN4(INT,vp_uclip,VPUCLIP,vpuclip,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_color,VPCOLOR,vpcolor,INT)
FCALLSCFUN4(INT,vp_coltab,VPCOLTAB,vpcoltab,INT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN4(INT,vp_dash,VPDASH,vpdash,INT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_draw,VPDRAW,vpdraw,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_udraw,VPUDRAW,vpudraw,FLOAT,FLOAT)
FCALLSCFUN0(INT,vp_egroup,VPEGROUP,vpegroup)
FCALLSCFUN0(INT,vp_endplot,VPENDPLOT,vpendplot)
FCALLSCFUN0(INT,vp_erase,VPERASE,vperase)
FCALLSCFUN1(INT,vp_fat,VPFAT,vpfat,INT)
FCALLSCFUN1(INT,vp_file,VPFILE,vpfile,PSTRING)
FCALLSCFUN3(INT,vp_fill,VPFILL,vpfill,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_ufill,VPUFILL,vpufill,PFLOAT,PFLOAT,INT)
FCALLSCFUN7(INT,vp_gtext,VPGTEXT,vpgtext,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,PSTRING)
FCALLSCFUN7(INT,vp_ugtext,VPUGTEXT,vpugtext,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,PSTRING)
FCALLSCFUN4(INT,vp_hatchload,VPHATCHLOAD,vphatchload,INT,INT,INT,PINT)
FCALLSCFUN1(INT,vp_message,VPMESSAGE,vpmessage,PSTRING)
FCALLSCFUN2(INT,vp_move,VPMOVE,vpmove,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_umove,VPUMOVE,vpumove,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_orig,VPORIG,vporig,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_uorig,VPUORIG,vpuorig,FLOAT,FLOAT)
FCALLSCFUN5(INT,vp_patload,VPPATLOAD,vppatload,INT,INT,INT,INT,PINT)
FCALLSCFUN2(INT,vp_pendn,VPPENDN,vppendn,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_upendn,VPUPENDN,vpupendn,FLOAT,FLOAT)
FCALLSCFUN0(INT,vp_penup,VPPENUP,vppenup)
FCALLSCFUN3(INT,vp_pline,VPPLINE,vppline,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_upline,VPUPLINE,vpupline,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_plot,VPPLOT,vpplot,FLOAT,FLOAT,INT)
FCALLSCFUN3(INT,vp_uplot,VPUPLOT,vpuplot,FLOAT,FLOAT,INT)
FCALLSCFUN5(INT,vp_pmark,VPPMARK,vppmark,INT,INT,INT,PFLOAT,PFLOAT)
FCALLSCFUN5(INT,vp_upmark,VPUPMARK,vpupmark,INT,INT,INT,PFLOAT,PFLOAT)
FCALLSCFUN0(INT,vp_purge,VPPURGE,vppurge)
FCALLSCFUN2(INT,vp_rascoltab,VPRASCOLTAB,vprascoltab,INT,PSTRING)
FCALLSCFUN2(INT,vp_scale,VPSCALE,vpscale,FLOAT,FLOAT)
FCALLSCFUN3(INT,vp_setdash,VPSETDASH,vpsetdash,PFLOAT,PFLOAT,INT)
FCALLSCFUN4(INT,vp_stretch,VPSTRETCH,vpstretch,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_style,VPSTYLE,vpstyle,INT)
FCALLSCFUN5(INT,vp_text,VPTEXT,vptext,FLOAT,FLOAT,INT,INT,PSTRING)
FCALLSCFUN5(INT,vp_utext,VPUTEXT,vputext,FLOAT,FLOAT,INT,INT,PSTRING)
FCALLSCFUN3(INT,vp_tfont,VPTFONT,vptfont,INT,INT,INT)
FCALLSCFUN2(INT,vp_tjust,VPTJUST,vptjust,INT,INT)
FCALLSCFUN2(INT,vp_where,VPWHERE,vpwhere,PFLOAT,PFLOAT)
FCALLSCFUN5(INT,vp_text,VPWTEXT,vpwtext,FLOAT,FLOAT,INT,INT,PSTRING)
FCALLSCFUN13(INT,vp_raster,VPRASTER,vpraster,PVOID,INT,INT,INT,INT,INT,FLOAT,FLOAT,FLOAT,PFLOAT,PFLOAT,INT,INT)

==> seplib-6.5.2.tar.gz: seplib-6.5.2/vplot/libvplot/fortstubs90.c <==
#include <sitedef.h>
#include "cfortran.h"
#include <unistd.h>
#define  NO_VPLOT_DEFINES 2
#include <vplot.h>

#include <cfortran.h>


int svpfilep (int filepntr)
{
extern FILE    *fdopen ();
    vp_filep (fdopen (filepntr, "w"));
}


FCALLSCFUN1(INT,svpfilep,VPFILEP,vpfilep,INT)
FCALLSCFUN5(INT,name_to_coltab,NAMETOCOLTAB,nametocoltab,STRING,INT,PFLOAT,PFLOAT,PFLOAT)
FCALLSCFUN6(INT,vp_area,VPAREA,vparea,PFLOAT,PFLOAT,INT,INT,INT,INT)
FCALLSCFUN6(INT,vp_uarea,VPUAREA,vpuarea,PFLOAT,PFLOAT,INT,INT,INT,INT)
FCALLSCFUN5(INT,vp_arrow,VPARROW,vparrow,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN5(INT,vp_uarrow,VPUARROW,vpuarrow,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_bgroup,VPBGROUP,vpbgroup,STRING)
FCALLSCFUN0(INT,vp_break,VPBREAK,vpbreak)
FCALLSCFUN4(INT,vp_clip,VPCLIP,vpclip,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN4(INT,vp_uclip,VPUCLIP,vpuclip,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_color,VPCOLOR,vpcolor,INT)
FCALLSCFUN4(INT,vp_coltab,VPCOLTAB,vpcoltab,INT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN4(INT,vp_dash,VPDASH,vpdash,INT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_draw,VPDRAW,vpdraw,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_udraw,VPUDRAW,vpudraw,FLOAT,FLOAT)
FCALLSCFUN0(INT,vp_egroup,VPEGROUP,vpegroup)
FCALLSCFUN0(INT,vp_endplot,VPENDPLOT,vpendplot)
FCALLSCFUN0(INT,vp_erase,VPERASE,vperase)
FCALLSCFUN1(INT,vp_fat,VPFAT,vpfat,INT)
FCALLSCFUN1(INT,vp_file,VPFILE,vpfile,STRING)
FCALLSCFUN3(INT,vp_fill,VPFILL,vpfill,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_ufill,VPUFILL,vpufill,PFLOAT,PFLOAT,INT)
FCALLSCFUN7(INT,vp_gtext,VPGTEXT,vpgtext,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,STRING)
FCALLSCFUN7(INT,vp_ugtext,VPUGTEXT,vpugtext,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,FLOAT,STRING)
FCALLSCFUN4(INT,vp_hatchload,VPHATCHLOAD,vphatchload,INT,INT,INT,PINT)
FCALLSCFUN1(INT,vp_message,VPMESSAGE,vpmessage,STRING)
FCALLSCFUN2(INT,vp_move,VPMOVE,vpmove,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_umove,VPUMOVE,vpumove,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_orig,VPORIG,vporig,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_uorig,VPUORIG,vpuorig,FLOAT,FLOAT)
FCALLSCFUN5(INT,vp_patload,VPPATLOAD,vppatload,INT,INT,INT,INT,PINT)
FCALLSCFUN2(INT,vp_pendn,VPPENDN,vppendn,FLOAT,FLOAT)
FCALLSCFUN2(INT,vp_upendn,VPUPENDN,vpupendn,FLOAT,FLOAT)
FCALLSCFUN0(INT,vp_penup,VPPENUP,vppenup)
FCALLSCFUN3(INT,vp_pline,VPPLINE,vppline,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_upline,VPUPLINE,vpupline,PFLOAT,PFLOAT,INT)
FCALLSCFUN3(INT,vp_plot,VPPLOT,vpplot,FLOAT,FLOAT,INT)
FCALLSCFUN3(INT,vp_uplot,VPUPLOT,vpuplot,FLOAT,FLOAT,INT)
FCALLSCFUN5(INT,vp_pmark,VPPMARK,vppmark,INT,INT,INT,PFLOAT,PFLOAT)
FCALLSCFUN5(INT,vp_upmark,VPUPMARK,vpupmark,INT,INT,INT,PFLOAT,PFLOAT)
FCALLSCFUN0(INT,vp_purge,VPPURGE,vppurge)
FCALLSCFUN2(INT,vp_rascoltab,VPRASCOLTAB,vprascoltab,INT,STRING)
FCALLSCFUN2(INT,vp_scale,VPSCALE,vpscale,FLOAT,FLOAT)
FCALLSCFUN3(INT,vp_setdash,VPSETDASH,vpsetdash,PFLOAT,PFLOAT,INT)
FCALLSCFUN4(INT,vp_stretch,VPSTRETCH,vpstretch,FLOAT,FLOAT,FLOAT,FLOAT)
FCALLSCFUN1(INT,vp_style,VPSTYLE,vpstyle,INT)
FCALLSCFUN5(INT,vp_text,VPTEXT,vptext,FLOAT,FLOAT,INT,INT,STRING)
FCALLSCFUN5(INT,vp_utext,VPUTEXT,vputext,FLOAT,FLOAT,INT,INT,STRING)
FCALLSCFUN3(INT,vp_tfont,VPTFONT,vptfont,INT,INT,INT)
FCALLSCFUN2(INT,vp_tjust,VPTJUST,vptjust,INT,INT)
FCALLSCFUN2(INT,vp_where,VPWHERE,vpwhere,PFLOAT,PFLOAT)
FCALLSCFUN5(INT,vp_text,VPWTEXT,vpwtext,FLOAT,FLOAT,INT,INT,STRING)
FCALLSCFUN13(INT,vp_raster,VPRASTER,vpraster,PVOID,INT,INT,INT,INT,INT,FLOAT,FLOAT,FLOAT,PFLOAT,PFLOAT,INT,INT)
